@@ -34,7 +34,10 @@
 
 #include "panel-schemas.h"
 #include "panel-profile.h"
+#ifdef HAVE_X11
+#include "xstuff.h"
 #include "panel-xutils.h"
+#endif
 
 #define DEFAULT_MOUSE_MODIFIER GDK_MOD1_MASK
 
@@ -46,8 +49,8 @@ typedef struct {
 } PanelBinding;
 
 static gboolean initialised = FALSE;
-static GSettings *marco_settings = NULL; 
-static GSettings *marco_keybindings_settings = NULL; 
+static GSettings *marco_settings = NULL;
+static GSettings *marco_keybindings_settings = NULL;
 
 static PanelBinding bindings [] = {
 	{ MARCO_ACTIVATE_WINDOW_MENU_KEY, "popup-panel-menu", 0, 0 },
@@ -114,7 +117,7 @@ panel_binding_set_entry (PanelBinding  *binding,
 {
 	binding_set = get_binding_set (binding_set);
 
-        gtk_binding_entry_add_signal (binding_set,	
+        gtk_binding_entry_add_signal (binding_set,
 				      binding->keyval,
 				      binding->modifiers,
 				      binding->signal,
@@ -241,10 +244,17 @@ panel_bindings_set_entries (GtkBindingSet *binding_set)
 guint
 panel_bindings_get_mouse_button_modifier_keymask (void)
 {
+#ifdef HAVE_X11
+	if (!is_using_x11 ())
+		return 0;
+
 	g_assert (mouse_button_modifier_keymask != 0);
 
 	if (!initialised)
 		panel_bindings_initialise ();
 
 	return panel_get_real_modifier_mask (mouse_button_modifier_keymask);
+#else
+	return 0;
+#endif
 }
